==> windmill_api-1.450.1-py3-none-any.whl: windmill_api/models/get_settings_response_200_ai_resource.py <==
from typing import Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

T = TypeVar("T", bound="GetSettingsResponse200AiResource")


@_attrs_define
class GetSettingsResponse200AiResource:
    """
    Attributes:
        path (str):
        provider (str):
    """

    path: str
    provider: str
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        path = self.path
        provider = self.provider

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "path": path,
                "provider": provider,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        path = d.pop("path")

        provider = d.pop("provider")

        get_settings_response_200_ai_resource = cls(
            path=path,
            provider=provider,
        )

        get_settings_response_200_ai_resource.additional_properties = d
        return get_settings_response_200_ai_resource

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> windmill_api-1.469.0-py3-none-any.whl: windmill_api/models/get_settings_response_200_ai_resource.py <==
from typing import Any, Dict, List, Type, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..models.get_settings_response_200_ai_resource_provider import GetSettingsResponse200AiResourceProvider

T = TypeVar("T", bound="GetSettingsResponse200AiResource")


@_attrs_define
class GetSettingsResponse200AiResource:
    """
    Attributes:
        path (str):
        provider (GetSettingsResponse200AiResourceProvider):
    """

    path: str
    provider: GetSettingsResponse200AiResourceProvider
    additional_properties: Dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        path = self.path
        provider = self.provider.value

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "path": path,
                "provider": provider,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        path = d.pop("path")

        provider = GetSettingsResponse200AiResourceProvider(d.pop("provider"))

        get_settings_response_200_ai_resource = cls(
            path=path,
            provider=provider,
        )

        get_settings_response_200_ai_resource.additional_properties = d
        return get_settings_response_200_ai_resource

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
